==> mysql-admin_1.0.18.orig.tar.gz: mysql-administrator-1.0.18/mysql-administrator/library/tests/test_restore_backup/r/mysql_41_cp1251.mysqldump.etalon.sql <==
-- MySQL dump 10.8
--
-- Host: localhost    Database: test
-- ------------------------------------------------------
-- Server version	4.1.7-nt

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE="NO_AUTO_VALUE_ON_ZERO" */;

--
-- Current Database: `test`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `test`;

USE `test`;

--
-- Table structure for table `t3`
--

DROP TABLE IF EXISTS `t3`;
CREATE TABLE `t3` (
  `f1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `t3`
--


/*!40000 ALTER TABLE `t3` DISABLE KEYS */;
LOCK TABLES `t3` WRITE;
INSERT INTO `t3` VALUES ('v1'),('v2');
UNLOCK TABLES;
/*!40000 ALTER TABLE `t3` ENABLE KEYS */;

--
-- Table structure for table `таблица1`
--

DROP TABLE IF EXISTS `таблица1`;
CREATE TABLE `таблица1` (
  `поле2` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `таблица1`
--


/*!40000 ALTER TABLE `таблица1` DISABLE KEYS */;
LOCK TABLES `таблица1` WRITE;
INSERT INTO `таблица1` VALUES ('значение3'),('значение4'),('значение5');
UNLOCK TABLES;
/*!40000 ALTER TABLE `таблица1` ENABLE KEYS */;

--
-- Table structure for table `таблица2`
--

DROP TABLE IF EXISTS `таблица2`;
CREATE TABLE `таблица2` (
  `поле1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `таблица2`
--


/*!40000 ALTER TABLE `таблица2` DISABLE KEYS */;
LOCK TABLES `таблица2` WRITE;
INSERT INTO `таблица2` VALUES ('значение1'),('значение2');
UNLOCK TABLES;
/*!40000 ALTER TABLE `таблица2` ENABLE KEYS */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;

==> mysql-admin_1.1.10.orig.tar.gz: mysql-administrator-1.1.10/mysql-administrator/library/tests/test_restore_backup/r/mysql_41_cp1251.mysqldump.etalon.sql <==
-- MySQL dump 10.9
--
-- ------------------------------------------------------

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE="NO_AUTO_VALUE_ON_ZERO" */;

--
-- Current Database: `test`
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ `test` /*!40100 DEFAULT CHARACTER SET latin1 */;

USE `test`;

--
-- Table structure for table `t3`
--

DROP TABLE IF EXISTS `t3`;
CREATE TABLE `t3` (
  `f1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `t3`
--


/*!40000 ALTER TABLE `t3` DISABLE KEYS */;
LOCK TABLES `t3` WRITE;
INSERT INTO `t3` VALUES ('v1'),('v2');
UNLOCK TABLES;
/*!40000 ALTER TABLE `t3` ENABLE KEYS */;

--
-- Table structure for table `таблица1`
--

DROP TABLE IF EXISTS `таблица1`;
CREATE TABLE `таблица1` (
  `поле2` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `таблица1`
--


/*!40000 ALTER TABLE `таблица1` DISABLE KEYS */;
LOCK TABLES `таблица1` WRITE;
INSERT INTO `таблица1` VALUES ('значение3'),('значение4'),('значение5');
UNLOCK TABLES;
/*!40000 ALTER TABLE `таблица1` ENABLE KEYS */;

--
-- Table structure for table `таблица2`
--

DROP TABLE IF EXISTS `таблица2`;
CREATE TABLE `таблица2` (
  `поле1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

--
-- Dumping data for table `таблица2`
--


/*!40000 ALTER TABLE `таблица2` DISABLE KEYS */;
LOCK TABLES `таблица2` WRITE;
INSERT INTO `таблица2` VALUES ('значение1'),('значение2');
UNLOCK TABLES;
/*!40000 ALTER TABLE `таблица2` ENABLE KEYS */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
